@@ -14,12 +14,12 @@ int rand_bytes(uint8_t *output, int len);
 
 #include "encrypt.h"
 
-void *init_data() {
+void * init_data() {
     return malloc(1);
 }
 
-obfs *new_obfs() {
-    obfs *self = (obfs *) malloc(sizeof(obfs));
+obfs * new_obfs() {
+    obfs * self = (obfs*)malloc(sizeof(obfs));
     self->l_data = NULL;
     return self;
 }
@@ -40,7 +40,8 @@ void dispose_obfs(obfs *self) {
     free(self);
 }
 
-obfs_class *new_obfs_class(char *plugin_name) {
+obfs_class * new_obfs_class(char *plugin_name)
+{
     if (plugin_name == NULL)
         return NULL;
     if (strcmp(plugin_name, "origin") == 0)
@@ -50,7 +51,7 @@ obfs_class *new_obfs_class(char *plugin_name) {
     init_crc32_table();
     init_shift128plus();
     if (strcmp(plugin_name, "http_simple") == 0) {
-        obfs_class *plugin = (obfs_class *) malloc(sizeof(obfs_class));
+        obfs_class * plugin = (obfs_class*)malloc(sizeof(obfs_class));
         plugin->init_data = init_data;
         plugin->new_obfs = http_simple_new_obfs;
         plugin->get_overhead = get_overhead;
@@ -63,7 +64,7 @@ obfs_class *new_obfs_class(char *plugin_name) {
 
         return plugin;
     } else if (strcmp(plugin_name, "http_post") == 0) {
-        obfs_class *plugin = (obfs_class *) malloc(sizeof(obfs_class));
+        obfs_class * plugin = (obfs_class*)malloc(sizeof(obfs_class));
         plugin->init_data = init_data;
         plugin->new_obfs = http_simple_new_obfs;
         plugin->get_overhead = get_overhead;
@@ -76,7 +77,7 @@ obfs_class *new_obfs_class(char *plugin_name) {
 
         return plugin;
     } else if (strcmp(plugin_name, "tls1.2_ticket_auth") == 0) {
-        obfs_class *plugin = (obfs_class *) malloc(sizeof(obfs_class));
+        obfs_class * plugin = (obfs_class*)malloc(sizeof(obfs_class));
         plugin->init_data = tls12_ticket_auth_init_data;
         plugin->new_obfs = tls12_ticket_auth_new_obfs;
         plugin->get_overhead = tls12_ticket_auth_get_overhead;
@@ -88,36 +89,36 @@ obfs_class *new_obfs_class(char *plugin_name) {
         plugin->client_decode = tls12_ticket_auth_client_decode;
 
         return plugin;
-        /*} else if (strcmp(plugin_name, "verify_simple") == 0) {
-            obfs_class * plugin = (obfs_class*)malloc(sizeof(obfs_class));
-            plugin->init_data = init_data;
-            plugin->new_obfs = verify_simple_new_obfs;
-            plugin->get_server_info = get_server_info;
-            plugin->set_server_info = set_server_info;
-            plugin->dispose = verify_simple_dispose;
+    /*} else if (strcmp(plugin_name, "verify_simple") == 0) {
+        obfs_class * plugin = (obfs_class*)malloc(sizeof(obfs_class));
+        plugin->init_data = init_data;
+        plugin->new_obfs = verify_simple_new_obfs;
+        plugin->get_server_info = get_server_info;
+        plugin->set_server_info = set_server_info;
+        plugin->dispose = verify_simple_dispose;
 
-            plugin->client_pre_encrypt = verify_simple_client_pre_encrypt;
-            plugin->client_post_decrypt = verify_simple_client_post_decrypt;
-            plugin->client_udp_pre_encrypt = NULL;
-            plugin->client_udp_post_decrypt = NULL;
+        plugin->client_pre_encrypt = verify_simple_client_pre_encrypt;
+        plugin->client_post_decrypt = verify_simple_client_post_decrypt;
+        plugin->client_udp_pre_encrypt = NULL;
+        plugin->client_udp_post_decrypt = NULL;
 
-            return plugin;
-        } else if (strcmp(plugin_name, "auth_simple") == 0) {
-            obfs_class * plugin = (obfs_class*)malloc(sizeof(obfs_class));
-            plugin->init_data = auth_simple_init_data;
-            plugin->new_obfs = auth_simple_new_obfs;
-            plugin->get_server_info = get_server_info;
-            plugin->set_server_info = set_server_info;
-            plugin->dispose = auth_simple_dispose;
+        return plugin;
+    } else if (strcmp(plugin_name, "auth_simple") == 0) {
+        obfs_class * plugin = (obfs_class*)malloc(sizeof(obfs_class));
+        plugin->init_data = auth_simple_init_data;
+        plugin->new_obfs = auth_simple_new_obfs;
+        plugin->get_server_info = get_server_info;
+        plugin->set_server_info = set_server_info;
+        plugin->dispose = auth_simple_dispose;
 
-            plugin->client_pre_encrypt = auth_simple_client_pre_encrypt;
-            plugin->client_post_decrypt = auth_simple_client_post_decrypt;
-            plugin->client_udp_pre_encrypt = NULL;
-            plugin->client_udp_post_decrypt = NULL;
+        plugin->client_pre_encrypt = auth_simple_client_pre_encrypt;
+        plugin->client_post_decrypt = auth_simple_client_post_decrypt;
+        plugin->client_udp_pre_encrypt = NULL;
+        plugin->client_udp_post_decrypt = NULL;
 
-            return plugin;*/
+        return plugin;*/
     } else if (strcmp(plugin_name, "auth_sha1") == 0) {
-        obfs_class *plugin = (obfs_class *) malloc(sizeof(obfs_class));
+        obfs_class * plugin = (obfs_class*)malloc(sizeof(obfs_class));
         plugin->init_data = auth_simple_init_data;
         plugin->new_obfs = auth_simple_new_obfs;
         plugin->get_overhead = get_overhead;
@@ -132,7 +133,7 @@ obfs_class *new_obfs_class(char *plugin_name) {
 
         return plugin;
     } else if (strcmp(plugin_name, "auth_sha1_v2") == 0) {
-        obfs_class *plugin = (obfs_class *) malloc(sizeof(obfs_class));
+        obfs_class * plugin = (obfs_class*)malloc(sizeof(obfs_class));
         plugin->init_data = auth_simple_init_data;
         plugin->new_obfs = auth_simple_new_obfs;
         plugin->get_overhead = get_overhead;
@@ -147,7 +148,7 @@ obfs_class *new_obfs_class(char *plugin_name) {
 
         return plugin;
     } else if (strcmp(plugin_name, "auth_sha1_v4") == 0) {
-        obfs_class *plugin = (obfs_class *) malloc(sizeof(obfs_class));
+        obfs_class * plugin = (obfs_class*)malloc(sizeof(obfs_class));
         plugin->init_data = auth_simple_init_data;
         plugin->new_obfs = auth_simple_new_obfs;
         plugin->get_overhead = get_overhead;
@@ -162,10 +163,9 @@ obfs_class *new_obfs_class(char *plugin_name) {
 
         return plugin;
     } else if (strcmp(plugin_name, "auth_aes128_md5") == 0 || strcmp(plugin_name, "auth_aes128_sha1") == 0) {
-        obfs_class *plugin = (obfs_class *) malloc(sizeof(obfs_class));
+        obfs_class * plugin = (obfs_class*)malloc(sizeof(obfs_class));
         plugin->init_data = auth_simple_init_data;
-        plugin->new_obfs = strcmp(plugin_name, "auth_aes128_md5") == 0 ?
-                           auth_aes128_md5_new_obfs : auth_aes128_sha1_new_obfs;
+        plugin->new_obfs = strcmp(plugin_name, "auth_aes128_md5") == 0 ? auth_aes128_md5_new_obfs : auth_aes128_sha1_new_obfs;
         plugin->get_overhead = auth_aes128_sha1_get_overhead;
         plugin->get_server_info = get_server_info;
         plugin->set_server_info = set_server_info;
@@ -178,12 +178,12 @@ obfs_class *new_obfs_class(char *plugin_name) {
 
         return plugin;
     } else if (strcmp(plugin_name, "auth_chain_a") == 0) {
-        obfs_class *plugin = (obfs_class *) malloc(sizeof(obfs_class));
+        obfs_class * plugin = (obfs_class*)malloc(sizeof(obfs_class));
         plugin->init_data = auth_chain_a_init_data;
         plugin->new_obfs = auth_chain_a_new_obfs;
         plugin->get_overhead = auth_chain_a_get_overhead;
         plugin->get_server_info = get_server_info;
-        plugin->set_server_info = auth_chain_a_set_server_info;
+        plugin->set_server_info = set_server_info;
         plugin->dispose = auth_chain_a_dispose;
 
         plugin->client_pre_encrypt = auth_chain_a_client_pre_encrypt;
@@ -191,66 +191,6 @@ obfs_class *new_obfs_class(char *plugin_name) {
         plugin->client_udp_pre_encrypt = auth_chain_a_client_udp_pre_encrypt;
         plugin->client_udp_post_decrypt = auth_chain_a_client_udp_post_decrypt;
 
-        return plugin;
-    } else if (strcmp(plugin_name, "auth_chain_b") == 0) {
-        obfs_class *plugin = (obfs_class *) malloc(sizeof(obfs_class));
-        plugin->init_data = auth_chain_b_init_data;
-        plugin->new_obfs = auth_chain_b_new_obfs;
-        plugin->get_overhead = auth_chain_b_get_overhead;
-        plugin->get_server_info = get_server_info;
-        plugin->set_server_info = auth_chain_b_set_server_info;
-        plugin->dispose = auth_chain_b_dispose;
-
-        plugin->client_pre_encrypt = auth_chain_a_client_pre_encrypt;
-        plugin->client_post_decrypt = auth_chain_a_client_post_decrypt;
-        plugin->client_udp_pre_encrypt = auth_chain_a_client_udp_pre_encrypt;
-        plugin->client_udp_post_decrypt = auth_chain_a_client_udp_post_decrypt;
-
-        return plugin;
-    } else if (strcmp(plugin_name, "auth_chain_c") == 0) {
-        obfs_class *plugin = (obfs_class *) malloc(sizeof(obfs_class));
-        plugin->init_data = auth_chain_c_init_data;
-        plugin->new_obfs = auth_chain_c_new_obfs;
-        plugin->get_overhead = auth_chain_c_get_overhead;
-        plugin->get_server_info = get_server_info;
-        plugin->set_server_info = auth_chain_c_set_server_info;
-        plugin->dispose = auth_chain_c_dispose;
-
-        plugin->client_pre_encrypt = auth_chain_a_client_pre_encrypt;
-        plugin->client_post_decrypt = auth_chain_a_client_post_decrypt;
-        plugin->client_udp_pre_encrypt = auth_chain_a_client_udp_pre_encrypt;
-        plugin->client_udp_post_decrypt = auth_chain_a_client_udp_post_decrypt;
-
-        return plugin;
-    } else if (strcmp(plugin_name, "auth_chain_d") == 0) {
-        obfs_class *plugin = (obfs_class *) malloc(sizeof(obfs_class));
-        plugin->init_data = auth_chain_d_init_data;
-        plugin->new_obfs = auth_chain_d_new_obfs;
-        plugin->get_overhead = auth_chain_d_get_overhead;
-        plugin->get_server_info = get_server_info;
-        plugin->set_server_info = auth_chain_d_set_server_info;
-        plugin->dispose = auth_chain_d_dispose;
-
-        plugin->client_pre_encrypt = auth_chain_a_client_pre_encrypt;
-        plugin->client_post_decrypt = auth_chain_a_client_post_decrypt;
-        plugin->client_udp_pre_encrypt = auth_chain_a_client_udp_pre_encrypt;
-        plugin->client_udp_post_decrypt = auth_chain_a_client_udp_post_decrypt;
-
-        return plugin;
-    } else if (strcmp(plugin_name, "auth_chain_e") == 0) {
-        obfs_class *plugin = (obfs_class *) malloc(sizeof(obfs_class));
-        plugin->init_data = auth_chain_e_init_data;
-        plugin->new_obfs = auth_chain_e_new_obfs;
-        plugin->get_overhead = auth_chain_e_get_overhead;
-        plugin->get_server_info = get_server_info;
-        plugin->set_server_info = auth_chain_e_set_server_info;
-        plugin->dispose = auth_chain_e_dispose;
-
-        plugin->client_pre_encrypt = auth_chain_a_client_pre_encrypt;
-        plugin->client_post_decrypt = auth_chain_a_client_post_decrypt;
-        plugin->client_udp_pre_encrypt = auth_chain_a_client_udp_pre_encrypt;
-        plugin->client_udp_post_decrypt = auth_chain_a_client_udp_post_decrypt;
-
         return plugin;
     }
     LOGE("Load obfs '%s' failed", plugin_name);
